examples Package
================

These examples all live in ``./examples`` in the source-distribution of RDFLib.

:mod:`conjunctive_graphs` Module
--------------------------------

.. automodule:: examples.conjunctive_graphs
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`custom_datatype` Module
-----------------------------

.. automodule:: examples.custom_datatype
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`custom_eval` Module
-------------------------

.. automodule:: examples.custom_eval
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`film` Module
------------------

.. automodule:: examples.film
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`foafpaths` Module
-----------------------

.. automodule:: examples.foafpaths
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`prepared_query` Module
----------------------------

.. automodule:: examples.prepared_query
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`resource` Module
----------------------

.. automodule:: examples.resource
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`rdfa_example` Module
----------------------

.. automodule:: examples.rdfa_example
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`simple_example` Module
----------------------------

.. automodule:: examples.simple_example
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sleepycat_example` Module
-----------------------------------

.. automodule:: examples.sleepycat_example
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`slice` Module
-------------------

.. automodule:: examples.slice
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`smushing` Module
-------------------

.. automodule:: examples.smushing
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sparql_query_example` Module
----------------------------------

.. automodule:: examples.sparql_query_example
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sparql_update_example` Module
-----------------------------------

.. automodule:: examples.sparql_update_example
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`sparqlstore_example` Module
-----------------------------------

.. automodule:: examples.sparqlstore_example
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`swap_primer` Module
-------------------------

.. automodule:: examples.swap_primer
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`transitive` Module
------------------------

.. automodule:: examples.transitive
    :members:
    :undoc-members:
    :show-inheritance:

